@@ -1,16 +1,16 @@
 import re
+import sys
 from typing import Optional, Sequence
 
 import click
 
 from sym.cli.helpers.ec2.factory import get_ec2_client
 
-from ..data.request_data import RequestData
 from ..decorators import command_require_bins, loses_interactivity, require_login
 from ..helpers.global_options import GlobalOptions
 from ..helpers.keywords_to_options import keywords_to_options
 from ..helpers.options import resource_argument
-from ..helpers.ssh import raw_ssh, start_ssh_session
+from ..helpers.ssh import raw_ssh, start_interactive_command, start_ssh_session
 from ..saml_clients.saml_client_factory import SAMLClientFactory
 from .sym import sym
 
@@ -168,6 +168,15 @@ def encode_options(kv):
         return {k: v}
 
 
+def use_interactive_ssm(is_a_tty: bool, **kwargs) -> bool:
+    traditional_ssh_flags = ["D", "L", "N", "R", "T", "W", "w", "X", "Y"]
+    for flag in traditional_ssh_flags:
+        # if one of these flags is set to a truthy value then we need to speak traditional SSH
+        if flag in kwargs and kwargs[flag]:
+            return False
+    return is_a_tty
+
+
 @sym.command(
     short_help="Start a SSH session",
     context_settings={
@@ -207,7 +216,6 @@ def ssh(
 
     """
     ssh_args = keywords_to_options(map(encode_options, kwargs.items()))
-
     if not destination:
         """
         Ansible will use SSH commands with no destination to audit the local SSH capabilities. When
@@ -216,18 +224,22 @@ def ssh(
         raw_ssh({"p": str(port)}, *ssh_args)
         return
 
-    request_data = RequestData("ssh", resource, options)
-
     client = SAMLClientFactory.create_saml_client(resource, options)
 
     client.dprint(f"ssh: args={ssh_args}")
     instance = get_ec2_client(client).load_instance_by_alias(destination)
     new_client = SAMLClientFactory.clone(client, aws_region=instance.region)
-    start_ssh_session(
-        new_client,
-        instance.instance_id,
-        port,
-        args=ssh_args,
-        command=command,
-        wrap=False,
-    )
+
+    interactive_ssm = use_interactive_ssm(is_a_tty=sys.stdin.isatty(), **kwargs)
+
+    if interactive_ssm:
+        start_interactive_command(new_client, instance.instance_id, command=command)
+    else:
+        start_ssh_session(
+            new_client,
+            instance.instance_id,
+            port,
+            args=ssh_args,
+            command=command,
+            wrap=False,
+        )
