@@ -2,6 +2,8 @@ from typing import Optional
 
 import click
 
+from sym.cli.helpers.sym_group import SymGroup
+
 from ..decorators import setup_segment, setup_sentry
 from ..helpers.constants import SegmentWriteKey, SentryDSN
 from ..helpers.envvar_option import EnvvarOption
@@ -12,7 +14,9 @@ from ..saml_clients.chooser import SAMLClientName, choose_saml_client, option_va
 from ..version import __version__
 
 
-@click.group(cls=SymGroup, context_settings={"help_option_names": ["-h", "--help"]})
+@click.group(
+    name="sym", cls=SymGroup, context_settings={"help_option_names": ["-h", "--help"]}
+)
 @click.option(
     "--saml-client",
     "saml_client_name",
@@ -32,8 +36,8 @@ from ..version import __version__
     hidden=True,
     envvar="SYM_LOG_DIR",
 )
-@resource_option
 @click.make_pass_decorator(GlobalOptions, ensure=True)
+@resource_option
 @setup_segment(write_key=SegmentWriteKey)
 @setup_sentry(dsn=SentryDSN, release=f"sym-cli@{__version__}")
 def sym(
