@@ -23,7 +23,7 @@ from ..errors import (
     TargetNotConnected,
     WrappedSubprocessError,
 )
-from ..helpers.boto import send_ssh_key, ssm_session
+from ..helpers.boto import send_ssh_key, ssm_interactive_command, ssm_ssh_session
 from ..helpers.config import Config, SymConfigFile
 from ..helpers.params import get_ssh_user
 from ..helpers.sym_group import SymGroup
@@ -308,5 +308,25 @@ def start_tunnel(client, instance: str, port: int):
 
     signal(SIGPIPE, handler)
 
-    with ssm_session(client, instance, port) as command:
+    with ssm_ssh_session(client, instance, port) as command:
+        client.exec(*command, suppress_=True)
+
+
+def start_interactive_command(client, instance: str, command: Sequence[str]):
+    SymGroup.reset_tees()
+    client.dprint("execing aws ssm interactive command")
+
+    def handler(signum, frame):
+        devnull = os.open(os.devnull, os.O_WRONLY)
+        os.dup2(devnull, sys.stdout.fileno())
+        # Set error state on session end.
+        # If the connection was actually successful,
+        # the parent thread will re-set a success state.
+        # This is the only reliable way to avoid error
+        # loops with Ansible due to missing SSH public keys.
+        Config.touch_instance(instance, error=True)
+
+    signal(SIGPIPE, handler)
+
+    with ssm_interactive_command(client, instance, get_ssh_user(), command) as command:
         client.exec(*command, suppress_=True)
