@@ -3,7 +3,7 @@ from configparser import ConfigParser, NoOptionError
 from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 
-from ..decorators import intercept_errors, require_bins, run_subprocess
+from ..decorators import command_require_bins, intercept_errors, run_subprocess
 from ..errors import (
     ExpiredCredentials,
     FailedSubprocessError,
@@ -32,12 +32,12 @@ class Saml2Aws(SAMLClient):
     setup_help = "Run `saml2aws login`."
 
     resource: str
-    options: "GlobalOptions"
+    options: "GlobalOptionsBase"
     config_file: Final[SymConfigFile]
     _config: Optional[ConfigParser]
     _s2a_options: Final[Options]
 
-    def __init__(self, resource: str, *, options: "GlobalOptions") -> None:
+    def __init__(self, resource: str, *, options: "GlobalOptionsBase") -> None:
         super().__init__(resource, options=options)
         self.config_file = SymConfigFile(resource=resource, file_name="saml2aws.cfg")
         self._s2a_options = {
@@ -63,7 +63,7 @@ class Saml2Aws(SAMLClient):
 
     @intercept_errors(ErrorPatterns)
     @run_subprocess
-    @require_bins(binary)
+    @command_require_bins(binary)
     def _exec(self, *args: str, **opts: str) -> Iterator[Tuple[Argument, ...]]:
         self.log_subprocess_event(args)
         # saml2aws exec actually joins all the arguments into a single string and
@@ -80,7 +80,7 @@ class Saml2Aws(SAMLClient):
 
     @intercept_errors(ErrorPatterns, suppress=True)
     @run_subprocess
-    @require_bins(binary)
+    @command_require_bins(binary)
     def _login(self, show_prompt=False, force=False):
         if show_prompt:
             options = {**self._s2a_options, "skip_prompt": False}
